[PATCH] [TEST] Adding the missing SKIP import stmt
by Deepti B. Kalakeri
# HG changeset patch
# User Deepti B. Kalakeri <deeptik(a)linux.vnet.ibm.com>
# Date 1240244367 25200
# Node ID ee7cca75f1e6e46e16dc2f21868ae8836661eb8e
# Parent ced161a8198115797a6036f3f22e02d234439a76
[TEST] Adding the missing SKIP import stmt.
Signed-off-by: Deepti B. Kalakeri <deeptik(a)linux.vnet.ibm.com>
diff -r ced161a81981 -r ee7cca75f1e6 suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py
--- a/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py Wed Apr 15 20:19:31 2009 -0700
+++ b/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py Mon Apr 20 09:19:27 2009 -0700
@@ -27,7 +27,7 @@
from VirtLib import utils
from pywbem import WBEMConnection, CIMInstanceName
from CimTest.CimExt import CIMMethodClass, CIMClassMOF
-from CimTest.ReturnCodes import PASS, FAIL
+from CimTest.ReturnCodes import PASS, FAIL, SKIP
from XenKvmLib.enumclass import EnumInstances
from XenKvmLib.classes import get_typed_class, virt_types
from XenKvmLib.xm_virt_util import domain_list
15 years, 8 months
[PATCH] [TEST] #2 Update RPCS/04 to validate that the Network child pool can be created through the providers
by yunguol@cn.ibm.com
# HG changeset patch
# User Guolian Yun <yunguol(a)cn.ibm.com>
# Date 1240207150 25200
# Node ID fd53d858ff5fa251862bf36c26eafd79290c2f65
# Parent ced161a8198115797a6036f3f22e02d234439a76
[TEST] #2 Update RPCS/04 to validate that the Network child pool can be created through the providers
Updates from 1 to 2:
Test all types of networkpool including routed network, nat based network and isolated network
Tested for KVM with current sources
Signed-off-by: Guolian Yun<yunguol(a)cn.ibm.com>
diff -r 3220adb67645 -r 6d914f871271 suites/libvirt-cim/main.py
--- a/suites/libvirt-cim/main.py Sun Apr 19 16:34:19 2009 -0700
+++ b/suites/libvirt-cim/main.py Sun Apr 19 16:35:48 2009 -0700
@@ -107,12 +107,10 @@
cmd = "qemu -help"
ret, out = utils.run_remote(ip, cmd)
if ret != 0:
- return "Encountered an error querying for qemu"
-
- cmd = "qemu-kvm -help"
- ret, out = utils.run_remote(ip, cmd)
- if ret != 0:
- return "Encountered an error querying for qemu-kvm "
+ cmd = "qemu-kvm -help"
+ ret, out = utils.run_remote(ip, cmd)
+ if ret != 0:
+ return "Encountered an error querying for qemu-kvm and qemu "
cmd = "ps -ef | grep -v grep | grep cimserver"
rc, out = utils.run_remote(ip, cmd)
15 years, 8 months
[PATCH] [TEST] For localhost migration, do not copy image file to host
by Kaitlin Rupert
# HG changeset patch
# User Kaitlin Rupert <karupert(a)us.ibm.com>
# Date 1240184059 25200
# Node ID 3220adb67645abf3784876851de4eab6748e76b3
# Parent 7bac72ee3582b0bb822b9062234ae1989a464f60
[TEST] For localhost migration, do not copy image file to host
No need to do this step since the file already exists
Signed-off-by: Kaitlin Rupert <karupert(a)us.ibm.com>
diff -r 7bac72ee3582 -r 3220adb67645 suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py
--- a/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py Sun Apr 19 16:30:00 2009 -0700
+++ b/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py Sun Apr 19 16:34:19 2009 -0700
@@ -158,6 +158,10 @@
logger.error("Failed to get Disk RASD info for '%s'", test_dom)
return FAIL, req_image, backup_image
+ if t_sysname == s_sysname or t_sysname in s_sysname:
+ #Localhost migration, no need to copy image
+ return PASS, req_image, backup_image
+
# Check if the image file with the same name already exist on the machine.
# Back it up. Copy the required working image to the destination.
cmd = "ls -l %s" % req_image
15 years, 8 months
[PATCH] [TEST] Improve enum volumes
by Kaitlin Rupert
# HG changeset patch
# User Kaitlin Rupert <karupert(a)us.ibm.com>
# Date 1240002683 25200
# Node ID 5706fea95239f1633296e2fbce13ada882848e13
# Parent ced161a8198115797a6036f3f22e02d234439a76
[TEST] Improve enum volumes
The providers don't return a template RASD for volumes that libvirt is
unable to get volume info for. So the testsuite needs to do the same.
Also, don't use a hardcoded disk pool name - use the default value from const.py
Signed-off-by: Kaitlin Rupert <karupert(a)us.ibm.com>
diff -r ced161a81981 -r 5706fea95239 suites/libvirt-cim/lib/XenKvmLib/pool.py
--- a/suites/libvirt-cim/lib/XenKvmLib/pool.py Wed Apr 15 20:19:31 2009 -0700
+++ b/suites/libvirt-cim/lib/XenKvmLib/pool.py Fri Apr 17 14:11:23 2009 -0700
@@ -24,7 +24,7 @@
from CimTest.Globals import logger
from CimTest.ReturnCodes import PASS, FAIL
from XenKvmLib.classes import get_typed_class
-from XenKvmLib.const import get_provider_version
+from XenKvmLib.const import get_provider_version, default_pool_name
from XenKvmLib.enumclass import EnumInstances
from VirtLib.utils import run_remote
from XenKvmLib.xm_virt_util import virt2uri
@@ -83,13 +83,19 @@
def enum_volumes(virt, server):
volume = 0
cmd = "virsh -c %s vol-list %s | sed -e '1,2 d' -e '$ d'" % \
- (virt2uri(virt), 'cimtest-diskpool')
+ (virt2uri(virt), default_pool_name)
ret, out = run_remote(server ,cmd)
if ret != 0:
return None
lines = out.split("\n")
for line in lines:
- volume = volume + 1
+ vol = line.split()[0]
+ cmd = "virsh vol-info --pool cimtest-diskpool meep"
+ cmd = "virsh -c %s vol-info --pool %s %s" % (virt2uri(virt),
+ default_pool_name, vol)
+ ret, out = run_remote(server ,cmd)
+ if ret == 0:
+ volume = volume + 1
return volume
15 years, 8 months
Test Run Summary (Apr 20 2009): KVM on Fedora release 10.90 (Rawhide) with Pegasus
by Guo Lian Yun
=================================================
Test Run Summary (Apr 20 2009): KVM on Fedora release 10.90 (Rawhide) with
Pegasus
=================================================
Distro: Fedora release 10.90 (Rawhide)
Kernel: 2.6.29-0.24.rc0.git13.fc11.x86_64
libvirt: 0.6.2
Hypervisor: QEMU 0.10.0
CIMOM: Pegasus 2.7.2
Libvirt-cim revision: 852
Libvirt-cim changeset: 0c6f5aa107a8
Cimtest revision: 668
Cimtest changeset: ced161a81981
=================================================
FAIL : 6
XFAIL : 4
SKIP : 15
PASS : 135
-----------------
Total : 160
=================================================
FAIL Test Summary:
ResourcePoolConfigurationService - 04_CreateChildResourcePool.py: FAIL
ResourcePoolConfigurationService - 07_DeleteResourcePool.py: FAIL
SettingsDefineCapabilities - 01_forward.py: FAIL
VirtualSystemMigrationService - 06_remote_live_migration.py: FAIL
VirtualSystemMigrationService - 07_remote_offline_migration.py: FAIL
VirtualSystemMigrationService - 08_remote_restart_resume_migration.py:
FAIL
=================================================
XFAIL Test Summary:
ComputerSystem - 32_start_reboot.py: XFAIL
ComputerSystem - 33_suspend_reboot.py: XFAIL
VirtualSystemManagementService - 09_procrasd_persist.py: XFAIL
VirtualSystemManagementService - 16_removeresource.py: XFAIL
=================================================
SKIP Test Summary:
ComputerSystem - 02_nosystems.py: SKIP
LogicalDisk - 02_nodevs.py: SKIP
VSSD - 02_bootldr.py: SKIP
VirtualSystemMigrationService - 01_migratable_host.py: SKIP
VirtualSystemMigrationService - 02_host_migrate_type.py: SKIP
VirtualSystemMigrationService - 05_migratable_host_errs.py: SKIP
ERROR - NameError : global name 'SKIP' is not defined
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - NameError : global name 'SKIP' is not defined
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - NameError : global name 'SKIP' is not defined
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
=================================================
Full report:
--------------------------------------------------------------------
AllocationCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
AllocationCapabilities - 02_alloccap_gi_errs.py: PASS
--------------------------------------------------------------------
ComputerSystem - 01_enum.py: PASS
--------------------------------------------------------------------
ComputerSystem - 02_nosystems.py: SKIP
ERROR - System has defined domains; unable to run
--------------------------------------------------------------------
ComputerSystem - 03_defineVS.py: PASS
--------------------------------------------------------------------
ComputerSystem - 04_defineStartVS.py: PASS
--------------------------------------------------------------------
ComputerSystem - 05_activate_defined_start.py: PASS
--------------------------------------------------------------------
ComputerSystem - 06_paused_active_suspend.py: PASS
--------------------------------------------------------------------
ComputerSystem - 22_define_suspend.py: PASS
--------------------------------------------------------------------
ComputerSystem - 23_pause_pause.py: PASS
--------------------------------------------------------------------
ComputerSystem - 27_define_pause_errs.py: PASS
--------------------------------------------------------------------
ComputerSystem - 32_start_reboot.py: XFAIL
ERROR - Got CIM error CIM_ERR_FAILED: Unable to reboot domain:
this function is not supported by the hypervisor: virDomainReboot with
return code 1
ERROR - Exception: Unable reboot dom 'cs_test_domain'
InvokeMethod(RequestStateChange): CIM_ERR_FAILED: Unable to reboot domain:
this function is not supported by the hypervisor: virDomainReboot
Bug:<00005>
--------------------------------------------------------------------
ComputerSystem - 33_suspend_reboot.py: XFAIL
ERROR - Got CIM error CIM_ERR_NOT_SUPPORTED: State not
supported with return code 7
ERROR - Exception: Unable Suspend dom 'test_domain'
InvokeMethod(RequestStateChange): CIM_ERR_NOT_SUPPORTED: State not
supported
Bug:<00012>
--------------------------------------------------------------------
ComputerSystem - 35_start_reset.py: PASS
--------------------------------------------------------------------
ComputerSystem - 40_RSC_start.py: PASS
--------------------------------------------------------------------
ComputerSystem - 41_cs_to_settingdefinestate.py: PASS
--------------------------------------------------------------------
ComputerSystem - 42_cs_gi_errs.py: PASS
--------------------------------------------------------------------
ComputerSystemIndication - 01_created_indication.py: PASS
--------------------------------------------------------------------
ElementAllocatedFromPool - 01_forward.py: PASS
--------------------------------------------------------------------
ElementAllocatedFromPool - 02_reverse.py: PASS
--------------------------------------------------------------------
ElementAllocatedFromPool - 03_reverse_errs.py: PASS
--------------------------------------------------------------------
ElementAllocatedFromPool - 04_forward_errs.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 01_forward.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 02_reverse.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 03_forward_errs.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 05_hostsystem_cap.py: PASS
--------------------------------------------------------------------
ElementConforms - 01_forward.py: PASS
--------------------------------------------------------------------
ElementConforms - 02_reverse.py: PASS
--------------------------------------------------------------------
ElementConforms - 03_ectp_fwd_errs.py: PASS
--------------------------------------------------------------------
ElementConforms - 04_ectp_rev_errs.py: PASS
--------------------------------------------------------------------
ElementSettingData - 01_forward.py: PASS
--------------------------------------------------------------------
ElementSettingData - 03_esd_assoc_with_rasd_errs.py: PASS
--------------------------------------------------------------------
EnabledLogicalElementCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
EnabledLogicalElementCapabilities - 02_elecap_gi_errs.py: PASS
--------------------------------------------------------------------
HostSystem - 01_enum.py: PASS
--------------------------------------------------------------------
HostSystem - 02_hostsystem_to_rasd.py: PASS
--------------------------------------------------------------------
HostSystem - 03_hs_to_settdefcap.py: PASS
--------------------------------------------------------------------
HostSystem - 04_hs_to_EAPF.py: PASS
--------------------------------------------------------------------
HostSystem - 05_hs_gi_errs.py: PASS
--------------------------------------------------------------------
HostSystem - 06_hs_to_vsms.py: PASS
--------------------------------------------------------------------
HostedAccessPoint - 01_forward.py: PASS
--------------------------------------------------------------------
HostedAccessPoint - 02_reverse.py: PASS
--------------------------------------------------------------------
HostedDependency - 01_forward.py: PASS
--------------------------------------------------------------------
HostedDependency - 02_reverse.py: PASS
--------------------------------------------------------------------
HostedDependency - 03_enabledstate.py: PASS
--------------------------------------------------------------------
HostedDependency - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
HostedResourcePool - 01_forward.py: PASS
--------------------------------------------------------------------
HostedResourcePool - 02_reverse.py: PASS
--------------------------------------------------------------------
HostedResourcePool - 03_forward_errs.py: PASS
--------------------------------------------------------------------
HostedResourcePool - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
HostedService - 01_forward.py: PASS
--------------------------------------------------------------------
HostedService - 02_reverse.py: PASS
--------------------------------------------------------------------
HostedService - 03_forward_errs.py: PASS
--------------------------------------------------------------------
HostedService - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
KVMRedirectionSAP - 01_enum_KVMredSAP.py: PASS
--------------------------------------------------------------------
LogicalDisk - 01_disk.py: PASS
--------------------------------------------------------------------
LogicalDisk - 02_nodevs.py: SKIP
ERROR - System has defined domains; unable to run
--------------------------------------------------------------------
LogicalDisk - 03_ld_gi_errs.py: PASS
--------------------------------------------------------------------
Memory - 01_memory.py: PASS
--------------------------------------------------------------------
Memory - 02_defgetmem.py: PASS
--------------------------------------------------------------------
Memory - 03_mem_gi_errs.py: PASS
--------------------------------------------------------------------
NetworkPort - 01_netport.py: PASS
--------------------------------------------------------------------
NetworkPort - 02_np_gi_errors.py: PASS
--------------------------------------------------------------------
NetworkPort - 03_user_netport.py: PASS
--------------------------------------------------------------------
Processor - 01_processor.py: PASS
--------------------------------------------------------------------
Processor - 02_definesys_get_procs.py: PASS
--------------------------------------------------------------------
Processor - 03_proc_gi_errs.py: PASS
--------------------------------------------------------------------
Profile - 01_enum.py: PASS
--------------------------------------------------------------------
Profile - 02_profile_to_elec.py: PASS
--------------------------------------------------------------------
Profile - 03_rprofile_gi_errs.py: PASS
--------------------------------------------------------------------
RASD - 01_verify_rasd_fields.py: PASS
--------------------------------------------------------------------
RASD - 02_enum.py: PASS
--------------------------------------------------------------------
RASD - 03_rasd_errs.py: PASS
--------------------------------------------------------------------
RASD - 04_disk_rasd_size.py: PASS
--------------------------------------------------------------------
RASD - 05_disk_rasd_emu_type.py: PASS
--------------------------------------------------------------------
RedirectionService - 01_enum_crs.py: PASS
--------------------------------------------------------------------
RedirectionService - 02_enum_crscap.py: PASS
--------------------------------------------------------------------
RedirectionService - 03_RedirectionSAP_errs.py: PASS
--------------------------------------------------------------------
ReferencedProfile - 01_verify_refprof.py: PASS
--------------------------------------------------------------------
ReferencedProfile - 02_refprofile_errs.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 01_forward.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 02_reverse.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 03_forward_errs.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 05_RAPF_err.py: PASS
--------------------------------------------------------------------
ResourcePool - 01_enum.py: PASS
--------------------------------------------------------------------
ResourcePool - 02_rp_gi_errors.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationCapabilities - 02_rpcc_gi_errs.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 01_enum.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 02_rcps_gi_errors.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 03_CreateResourcePool.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 04_CreateChildResourcePool.py: FAIL
ERROR - Unexpected rc code 4 and description
CIM_ERR_INVALID_PARAMETER
InvokeMethod(CreateChildResourcePool): CIM_ERR_INVALID_PARAMETER
--------------------------------------------------------------------
ResourcePoolConfigurationService - 05_AddResourcesToResourcePool.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 06_RemoveResourcesFromResourcePool.py:
PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 07_DeleteResourcePool.py: FAIL
ERROR - Unexpected rc code 4 and description
CIM_ERR_INVALID_PARAMETER
InvokeMethod(DeleteResourcePool): CIM_ERR_INVALID_PARAMETER
--------------------------------------------------------------------
ServiceAccessBySAP - 01_forward.py: PASS
--------------------------------------------------------------------
ServiceAccessBySAP - 02_reverse.py: PASS
--------------------------------------------------------------------
SettingsDefine - 01_forward.py: PASS
--------------------------------------------------------------------
SettingsDefine - 02_reverse.py: PASS
--------------------------------------------------------------------
SettingsDefine - 03_sds_fwd_errs.py: PASS
--------------------------------------------------------------------
SettingsDefine - 04_sds_rev_errs.py: PASS
--------------------------------------------------------------------
SettingsDefineCapabilities - 01_forward.py: FAIL
ERROR - KVM_SettingsDefineCapabilities returned 40 ResourcePool
objects instead of 44
--------------------------------------------------------------------
SettingsDefineCapabilities - 03_forward_errs.py: PASS
--------------------------------------------------------------------
SettingsDefineCapabilities - 04_forward_vsmsdata.py: PASS
--------------------------------------------------------------------
SettingsDefineCapabilities - 05_reverse_vsmcap.py: PASS
--------------------------------------------------------------------
SystemDevice - 01_forward.py: PASS
--------------------------------------------------------------------
SystemDevice - 02_reverse.py: PASS
--------------------------------------------------------------------
SystemDevice - 03_fwderrs.py: PASS
--------------------------------------------------------------------
VSSD - 01_enum.py: PASS
--------------------------------------------------------------------
VSSD - 02_bootldr.py: SKIP
--------------------------------------------------------------------
VSSD - 03_vssd_gi_errs.py: PASS
--------------------------------------------------------------------
VSSD - 04_vssd_to_rasd.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementCapabilities - 02_vsmcap_gi_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 01_definesystem_name.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 02_destroysystem.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 03_definesystem_ess.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 04_definesystem_ers.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 05_destroysystem_neg.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 06_addresource.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 07_addresource_neg.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 08_modifyresource.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 09_procrasd_persist.py: XFAIL
--------------------------------------------------------------------
VirtualSystemManagementService - 10_hv_version.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 11_define_memrasdunits.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 12_referenced_config.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 13_refconfig_additional_devs.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 14_define_sys_disk.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 15_mod_system_settings.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 16_removeresource.py: XFAIL
ERROR - 0 RASD insts for domain/mouse:ps2
CIM_ERR_NOT_FOUND: No such instance (no device domain/mouse:ps2)
Bug:<00014>
--------------------------------------------------------------------
VirtualSystemManagementService - 17_removeresource_neg.py: PASS
--------------------------------------------------------------------
VirtualSystemMigrationCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemMigrationCapabilities - 02_vsmc_gi_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemMigrationService - 01_migratable_host.py: SKIP
--------------------------------------------------------------------
VirtualSystemMigrationService - 02_host_migrate_type.py: SKIP
--------------------------------------------------------------------
VirtualSystemMigrationService - 05_migratable_host_errs.py: SKIP
--------------------------------------------------------------------
VirtualSystemMigrationService - 06_remote_live_migration.py: FAIL
ERROR - NameError : global name 'SKIP' is not defined
Traceback (most recent call last):
File "./lib/XenKvmLib/const.py", line 139, in do_try
File "06_remote_live_migration.py", line 113, in main
status, s_sysname, t_sysname = check_mig_support(virt, options)
File
"/data/users/daisy/cimtest/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py",
line 99, in check_mig_support
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - None
--------------------------------------------------------------------
VirtualSystemMigrationService - 07_remote_offline_migration.py: FAIL
ERROR - NameError : global name 'SKIP' is not defined
Traceback (most recent call last):
File "./lib/XenKvmLib/const.py", line 139, in do_try
File "07_remote_offline_migration.py", line 96, in main
status, s_sysname, t_sysname = check_mig_support(virt, options)
File
"/data/users/daisy/cimtest/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py",
line 99, in check_mig_support
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - None
--------------------------------------------------------------------
VirtualSystemMigrationService - 08_remote_restart_resume_migration.py:
FAIL
ERROR - NameError : global name 'SKIP' is not defined
Traceback (most recent call last):
File "./lib/XenKvmLib/const.py", line 139, in do_try
File "08_remote_restart_resume_migration.py", line 117, in main
status, s_sysname, t_sysname = check_mig_support(virt, options)
File
"/data/users/daisy/cimtest/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py",
line 99, in check_mig_support
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - None
--------------------------------------------------------------------
VirtualSystemMigrationSettingData - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemMigrationSettingData - 02_vsmsd_gi_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemSettingDataComponent - 01_forward.py: PASS
--------------------------------------------------------------------
VirtualSystemSettingDataComponent - 02_reverse.py: PASS
--------------------------------------------------------------------
VirtualSystemSettingDataComponent - 03_vssdc_fwd_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemSettingDataComponent - 04_vssdc_rev_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemSnapshotService - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemSnapshotService - 02_vs_sservice_gi_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemSnapshotServiceCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemSnapshotServiceCapabilities - 02_vs_sservicecap_gi_errs.py:
PASS
--------------------------------------------------------------------
15 years, 8 months
Test Run Summary (Apr 20 2009): KVM on Fedora release 10 (Cambridge) with sfcb
by Guo Lian Yun
=================================================
Test Run Summary (Apr 20 2009): KVM on Fedora release 10 (Cambridge) with
sfcb
=================================================
Distro: Fedora release 10 (Cambridge)
Kernel: 2.6.27.15-170.2.24.fc10.x86_64
libvirt: 0.4.5
Hypervisor: QEMU 0.9.1
CIMOM: sfcb sfcbd 1.3.4preview
Libvirt-cim revision: 855
Libvirt-cim changeset: 4eef240f8ffc
Cimtest revision: 668
Cimtest changeset: ced161a81981
=================================================
FAIL : 7
XFAIL : 4
SKIP : 15
PASS : 134
-----------------
Total : 160
=================================================
FAIL Test Summary:
ComputerSystemIndication - 01_created_indication.py: FAIL
ResourcePoolConfigurationService - 04_CreateChildResourcePool.py: FAIL
ResourcePoolConfigurationService - 07_DeleteResourcePool.py: FAIL
SettingsDefineCapabilities - 01_forward.py: FAIL
VirtualSystemMigrationService - 06_remote_live_migration.py: FAIL
VirtualSystemMigrationService - 07_remote_offline_migration.py: FAIL
VirtualSystemMigrationService - 08_remote_restart_resume_migration.py:
FAIL
=================================================
XFAIL Test Summary:
ComputerSystem - 32_start_reboot.py: XFAIL
ComputerSystem - 33_suspend_reboot.py: XFAIL
VirtualSystemManagementService - 09_procrasd_persist.py: XFAIL
VirtualSystemManagementService - 16_removeresource.py: XFAIL
=================================================
SKIP Test Summary:
ComputerSystem - 02_nosystems.py: SKIP
LogicalDisk - 02_nodevs.py: SKIP
VSSD - 02_bootldr.py: SKIP
VirtualSystemMigrationService - 01_migratable_host.py: SKIP
VirtualSystemMigrationService - 02_host_migrate_type.py: SKIP
VirtualSystemMigrationService - 05_migratable_host_errs.py: SKIP
ERROR - NameError : global name 'SKIP' is not defined
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - NameError : global name 'SKIP' is not defined
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - NameError : global name 'SKIP' is not defined
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
=================================================
Full report:
--------------------------------------------------------------------
AllocationCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
AllocationCapabilities - 02_alloccap_gi_errs.py: PASS
--------------------------------------------------------------------
ComputerSystem - 01_enum.py: PASS
--------------------------------------------------------------------
ComputerSystem - 02_nosystems.py: SKIP
ERROR - System has defined domains; unable to run
--------------------------------------------------------------------
ComputerSystem - 03_defineVS.py: PASS
--------------------------------------------------------------------
ComputerSystem - 04_defineStartVS.py: PASS
--------------------------------------------------------------------
ComputerSystem - 05_activate_defined_start.py: PASS
--------------------------------------------------------------------
ComputerSystem - 06_paused_active_suspend.py: PASS
--------------------------------------------------------------------
ComputerSystem - 22_define_suspend.py: PASS
--------------------------------------------------------------------
ComputerSystem - 23_pause_pause.py: PASS
--------------------------------------------------------------------
ComputerSystem - 27_define_pause_errs.py: PASS
--------------------------------------------------------------------
ComputerSystem - 32_start_reboot.py: XFAIL
ERROR - Got CIM error Unable to reboot domain: this function is
not supported by the hypervisor: virDomainReboot with return code 1
ERROR - Exception: Unable reboot dom 'cs_test_domain'
InvokeMethod(RequestStateChange): Unable to reboot domain: this function
is not supported by the hypervisor: virDomainReboot
Bug:<00005>
--------------------------------------------------------------------
ComputerSystem - 33_suspend_reboot.py: XFAIL
ERROR - Got CIM error State not supported with return code 7
ERROR - Exception: Unable Suspend dom 'test_domain'
InvokeMethod(RequestStateChange): State not supported
Bug:<00012>
--------------------------------------------------------------------
ComputerSystem - 35_start_reset.py: PASS
--------------------------------------------------------------------
ComputerSystem - 40_RSC_start.py: PASS
--------------------------------------------------------------------
ComputerSystem - 41_cs_to_settingdefinestate.py: PASS
--------------------------------------------------------------------
ComputerSystem - 42_cs_gi_errs.py: PASS
--------------------------------------------------------------------
ComputerSystemIndication - 01_created_indication.py: FAIL
ERROR - Exception : Request Failed: 200
Traceback (most recent call last):
File "./lib/XenKvmLib/const.py", line 139, in do_try
File "01_created_indication.py", line 146, in main
sub_list, ind_names, dict = sub_ind(ip, virt)
File "01_created_indication.py", line 60, in sub_ind
sub.subscribe(dict['default_url'], dict['default_auth'])
File
"/data/users/daisy/cimtest/suites/libvirt-cim/lib/XenKvmLib/indication_tester.py",
line 345, in subscribe
"CreateInstance", auth_hdr)
File
"/data/users/daisy/cimtest/suites/libvirt-cim/lib/XenKvmLib/indication_tester.py",
line 330, in __do_cimpost
(resp.status, resp.reason))
Exception: Request Failed: 200
ERROR - None
--------------------------------------------------------------------
ElementAllocatedFromPool - 01_forward.py: PASS
--------------------------------------------------------------------
ElementAllocatedFromPool - 02_reverse.py: PASS
--------------------------------------------------------------------
ElementAllocatedFromPool - 03_reverse_errs.py: PASS
--------------------------------------------------------------------
ElementAllocatedFromPool - 04_forward_errs.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 01_forward.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 02_reverse.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 03_forward_errs.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
ElementCapabilities - 05_hostsystem_cap.py: PASS
--------------------------------------------------------------------
ElementConforms - 01_forward.py: PASS
--------------------------------------------------------------------
ElementConforms - 02_reverse.py: PASS
--------------------------------------------------------------------
ElementConforms - 03_ectp_fwd_errs.py: PASS
--------------------------------------------------------------------
ElementConforms - 04_ectp_rev_errs.py: PASS
--------------------------------------------------------------------
ElementSettingData - 01_forward.py: PASS
--------------------------------------------------------------------
ElementSettingData - 03_esd_assoc_with_rasd_errs.py: PASS
--------------------------------------------------------------------
EnabledLogicalElementCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
EnabledLogicalElementCapabilities - 02_elecap_gi_errs.py: PASS
--------------------------------------------------------------------
HostSystem - 01_enum.py: PASS
--------------------------------------------------------------------
HostSystem - 02_hostsystem_to_rasd.py: PASS
--------------------------------------------------------------------
HostSystem - 03_hs_to_settdefcap.py: PASS
--------------------------------------------------------------------
HostSystem - 04_hs_to_EAPF.py: PASS
--------------------------------------------------------------------
HostSystem - 05_hs_gi_errs.py: PASS
--------------------------------------------------------------------
HostSystem - 06_hs_to_vsms.py: PASS
--------------------------------------------------------------------
HostedAccessPoint - 01_forward.py: PASS
--------------------------------------------------------------------
HostedAccessPoint - 02_reverse.py: PASS
--------------------------------------------------------------------
HostedDependency - 01_forward.py: PASS
--------------------------------------------------------------------
HostedDependency - 02_reverse.py: PASS
--------------------------------------------------------------------
HostedDependency - 03_enabledstate.py: PASS
--------------------------------------------------------------------
HostedDependency - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
HostedResourcePool - 01_forward.py: PASS
--------------------------------------------------------------------
HostedResourcePool - 02_reverse.py: PASS
--------------------------------------------------------------------
HostedResourcePool - 03_forward_errs.py: PASS
--------------------------------------------------------------------
HostedResourcePool - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
HostedService - 01_forward.py: PASS
--------------------------------------------------------------------
HostedService - 02_reverse.py: PASS
--------------------------------------------------------------------
HostedService - 03_forward_errs.py: PASS
--------------------------------------------------------------------
HostedService - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
KVMRedirectionSAP - 01_enum_KVMredSAP.py: PASS
--------------------------------------------------------------------
LogicalDisk - 01_disk.py: PASS
--------------------------------------------------------------------
LogicalDisk - 02_nodevs.py: SKIP
ERROR - System has defined domains; unable to run
--------------------------------------------------------------------
LogicalDisk - 03_ld_gi_errs.py: PASS
--------------------------------------------------------------------
Memory - 01_memory.py: PASS
--------------------------------------------------------------------
Memory - 02_defgetmem.py: PASS
--------------------------------------------------------------------
Memory - 03_mem_gi_errs.py: PASS
--------------------------------------------------------------------
NetworkPort - 01_netport.py: PASS
--------------------------------------------------------------------
NetworkPort - 02_np_gi_errors.py: PASS
--------------------------------------------------------------------
NetworkPort - 03_user_netport.py: PASS
--------------------------------------------------------------------
Processor - 01_processor.py: PASS
--------------------------------------------------------------------
Processor - 02_definesys_get_procs.py: PASS
--------------------------------------------------------------------
Processor - 03_proc_gi_errs.py: PASS
--------------------------------------------------------------------
Profile - 01_enum.py: PASS
--------------------------------------------------------------------
Profile - 02_profile_to_elec.py: PASS
--------------------------------------------------------------------
Profile - 03_rprofile_gi_errs.py: PASS
--------------------------------------------------------------------
RASD - 01_verify_rasd_fields.py: PASS
--------------------------------------------------------------------
RASD - 02_enum.py: PASS
--------------------------------------------------------------------
RASD - 03_rasd_errs.py: PASS
--------------------------------------------------------------------
RASD - 04_disk_rasd_size.py: PASS
--------------------------------------------------------------------
RASD - 05_disk_rasd_emu_type.py: PASS
--------------------------------------------------------------------
RedirectionService - 01_enum_crs.py: PASS
--------------------------------------------------------------------
RedirectionService - 02_enum_crscap.py: PASS
--------------------------------------------------------------------
RedirectionService - 03_RedirectionSAP_errs.py: PASS
--------------------------------------------------------------------
ReferencedProfile - 01_verify_refprof.py: PASS
--------------------------------------------------------------------
ReferencedProfile - 02_refprofile_errs.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 01_forward.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 02_reverse.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 03_forward_errs.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 04_reverse_errs.py: PASS
--------------------------------------------------------------------
ResourceAllocationFromPool - 05_RAPF_err.py: PASS
--------------------------------------------------------------------
ResourcePool - 01_enum.py: PASS
--------------------------------------------------------------------
ResourcePool - 02_rp_gi_errors.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationCapabilities - 02_rpcc_gi_errs.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 01_enum.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 02_rcps_gi_errors.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 03_CreateResourcePool.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 04_CreateChildResourcePool.py: FAIL
ERROR - Unexpected rc code 4 and description One or more
parameter values passed to the method were invalid
InvokeMethod(CreateChildResourcePool): One or more parameter values passed
to the method were invalid
--------------------------------------------------------------------
ResourcePoolConfigurationService - 05_AddResourcesToResourcePool.py: PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 06_RemoveResourcesFromResourcePool.py:
PASS
--------------------------------------------------------------------
ResourcePoolConfigurationService - 07_DeleteResourcePool.py: FAIL
ERROR - Unexpected rc code 4 and description One or more
parameter values passed to the method were invalid
InvokeMethod(DeleteResourcePool): One or more parameter values passed to
the method were invalid
--------------------------------------------------------------------
ServiceAccessBySAP - 01_forward.py: PASS
--------------------------------------------------------------------
ServiceAccessBySAP - 02_reverse.py: PASS
--------------------------------------------------------------------
SettingsDefine - 01_forward.py: PASS
--------------------------------------------------------------------
SettingsDefine - 02_reverse.py: PASS
--------------------------------------------------------------------
SettingsDefine - 03_sds_fwd_errs.py: PASS
--------------------------------------------------------------------
SettingsDefine - 04_sds_rev_errs.py: PASS
--------------------------------------------------------------------
SettingsDefineCapabilities - 01_forward.py: FAIL
ERROR - KVM_SettingsDefineCapabilities returned 52 ResourcePool
objects instead of 56
--------------------------------------------------------------------
SettingsDefineCapabilities - 03_forward_errs.py: PASS
--------------------------------------------------------------------
SettingsDefineCapabilities - 04_forward_vsmsdata.py: PASS
--------------------------------------------------------------------
SettingsDefineCapabilities - 05_reverse_vsmcap.py: PASS
--------------------------------------------------------------------
SystemDevice - 01_forward.py: PASS
--------------------------------------------------------------------
SystemDevice - 02_reverse.py: PASS
--------------------------------------------------------------------
SystemDevice - 03_fwderrs.py: PASS
--------------------------------------------------------------------
VSSD - 01_enum.py: PASS
--------------------------------------------------------------------
VSSD - 02_bootldr.py: SKIP
--------------------------------------------------------------------
VSSD - 03_vssd_gi_errs.py: PASS
--------------------------------------------------------------------
VSSD - 04_vssd_to_rasd.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementCapabilities - 02_vsmcap_gi_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 01_definesystem_name.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 02_destroysystem.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 03_definesystem_ess.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 04_definesystem_ers.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 05_destroysystem_neg.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 06_addresource.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 07_addresource_neg.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 08_modifyresource.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 09_procrasd_persist.py: XFAIL
--------------------------------------------------------------------
VirtualSystemManagementService - 10_hv_version.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 11_define_memrasdunits.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 12_referenced_config.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 13_refconfig_additional_devs.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 14_define_sys_disk.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 15_mod_system_settings.py: PASS
--------------------------------------------------------------------
VirtualSystemManagementService - 16_removeresource.py: XFAIL
ERROR - 0 RASD insts for domain/mouse:ps2
No such instance (no device domain/mouse:ps2)
Bug:<00014>
--------------------------------------------------------------------
VirtualSystemManagementService - 17_removeresource_neg.py: PASS
--------------------------------------------------------------------
VirtualSystemMigrationCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemMigrationCapabilities - 02_vsmc_gi_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemMigrationService - 01_migratable_host.py: SKIP
--------------------------------------------------------------------
VirtualSystemMigrationService - 02_host_migrate_type.py: SKIP
--------------------------------------------------------------------
VirtualSystemMigrationService - 05_migratable_host_errs.py: SKIP
--------------------------------------------------------------------
VirtualSystemMigrationService - 06_remote_live_migration.py: FAIL
ERROR - NameError : global name 'SKIP' is not defined
Traceback (most recent call last):
File "./lib/XenKvmLib/const.py", line 139, in do_try
File "06_remote_live_migration.py", line 113, in main
status, s_sysname, t_sysname = check_mig_support(virt, options)
File
"/data/users/daisy/cimtest/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py",
line 99, in check_mig_support
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - None
--------------------------------------------------------------------
VirtualSystemMigrationService - 07_remote_offline_migration.py: FAIL
ERROR - NameError : global name 'SKIP' is not defined
Traceback (most recent call last):
File "./lib/XenKvmLib/const.py", line 139, in do_try
File "07_remote_offline_migration.py", line 96, in main
status, s_sysname, t_sysname = check_mig_support(virt, options)
File
"/data/users/daisy/cimtest/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py",
line 99, in check_mig_support
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - None
--------------------------------------------------------------------
VirtualSystemMigrationService - 08_remote_restart_resume_migration.py:
FAIL
ERROR - NameError : global name 'SKIP' is not defined
Traceback (most recent call last):
File "./lib/XenKvmLib/const.py", line 139, in do_try
File "08_remote_restart_resume_migration.py", line 117, in main
status, s_sysname, t_sysname = check_mig_support(virt, options)
File
"/data/users/daisy/cimtest/suites/libvirt-cim/lib/XenKvmLib/vsmigrations.py",
line 99, in check_mig_support
return SKIP, s_sysname, t_sysname
NameError: global name 'SKIP' is not defined
ERROR - None
--------------------------------------------------------------------
VirtualSystemMigrationSettingData - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemMigrationSettingData - 02_vsmsd_gi_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemSettingDataComponent - 01_forward.py: PASS
--------------------------------------------------------------------
VirtualSystemSettingDataComponent - 02_reverse.py: PASS
--------------------------------------------------------------------
VirtualSystemSettingDataComponent - 03_vssdc_fwd_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemSettingDataComponent - 04_vssdc_rev_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemSnapshotService - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemSnapshotService - 02_vs_sservice_gi_errs.py: PASS
--------------------------------------------------------------------
VirtualSystemSnapshotServiceCapabilities - 01_enum.py: PASS
--------------------------------------------------------------------
VirtualSystemSnapshotServiceCapabilities - 02_vs_sservicecap_gi_errs.py:
PASS
--------------------------------------------------------------------
15 years, 8 months
[PATCH] [TEST] Fix HS 03 to work with Xen on upstream libvirt
by Kaitlin Rupert
# HG changeset patch
# User Kaitlin Rupert <karupert(a)us.ibm.com>
# Date 1240000721 25200
# Node ID 6d9a4f2dd357dd62d05d0415a6af7b16f3fffd93
# Parent ced161a8198115797a6036f3f22e02d234439a76
[TEST] Fix HS 03 to work with Xen on upstream libvirt
Signed-off-by: Kaitlin Rupert <karupert(a)us.ibm.com>
diff -r ced161a81981 -r 6d9a4f2dd357 suites/libvirt-cim/cimtest/HostSystem/03_hs_to_settdefcap.py
--- a/suites/libvirt-cim/cimtest/HostSystem/03_hs_to_settdefcap.py Wed Apr 15 20:19:31 2009 -0700
+++ b/suites/libvirt-cim/cimtest/HostSystem/03_hs_to_settdefcap.py Fri Apr 17 13:38:41 2009 -0700
@@ -29,13 +29,15 @@
# Steps:
# 1. Create a guest.
# 2. Enumerate the HostSystem .
-# 3. Using the HostedResourcePool association, get the HostSystem instances on the system
-# 4. Using the ElementCapabilities association get the ProcessorPool, MemPool, DiskPool &
-# NetPool instances on the system.
-# 5. Using the SettingsDefineCapabilities association on the AllocationCapabilities, get
-# the (Default, Minimum, Maximum and Increment) instances for ProcRASD.
-# 6. Similarly for the MemRASD, DiskRASD & NetRASD get the SettingDefineCap assocn and \
-# get the instances for (Def, Min, Max and Inc).
+# 3. Using the HostedResourcePool association, get the HostSystem instances
+# on the system
+# 4. Using the ElementCapabilities association get the ProcessorPool,
+# MemPool, DiskPool & NetPool instances on the system.
+# 5. Using the SettingsDefineCapabilities association on the
+# AllocationCapabilities, get the (Default, Minimum, Maximum and Increment)
+# instances for ProcRASD.
+# 6. Similarly for the MemRASD, DiskRASD & NetRASD get the SettingDefineCap
+# assocn and get the instances for (Def, Min, Max and Inc).
#
# Feb 13 2008
@@ -228,6 +230,10 @@
exp_len = 8
if curr_cim_rev >= libvirt_rasd_new_changes:
exp_len = 16
+ if curr_cim_rev >= libvirt_rasd_dpool_changes:
+ volumes = enum_volumes(virt, server)
+ exp_len = volumes * 8
+
if virt == 'KVM':
if curr_cim_rev >= libvirt_rasd_new_changes and \
curr_cim_rev < libvirt_rasd_dpool_changes:
15 years, 8 months
[PATCH] Add support for creating filesystem type storage pools
by Kaitlin Rupert
# HG changeset patch
# User Kaitlin Rupert <karupert(a)us.ibm.com>
# Date 1239905650 25200
# Node ID 261a49710d0cb13c83e28f460583079db473d04f
# Parent 4574c6f289f29c9afd2bd3a3434360c17891e9fe
Add support for creating filesystem type storage pools
Signed-off-by: Kaitlin Rupert <karupert(a)us.ibm.com>
diff -r 4574c6f289f2 -r 261a49710d0c libxkutil/pool_parsing.c
--- a/libxkutil/pool_parsing.c Wed Apr 15 10:28:07 2009 -0700
+++ b/libxkutil/pool_parsing.c Thu Apr 16 11:14:10 2009 -0700
@@ -52,6 +52,11 @@
free(pool.forward_dev);
}
+static void cleanup_disk_pool(struct disk_pool pool) {
+ free(pool.path);
+ free(pool.device_path);
+}
+
void cleanup_virt_pool(struct virt_pool **pool)
{
struct virt_pool *_pool = *pool;
@@ -61,6 +66,8 @@
if (_pool->type == CIM_RES_TYPE_NET)
cleanup_net_pool(_pool->pool_info.net);
+ else if (_pool->type == CIM_RES_TYPE_DISK)
+ cleanup_disk_pool(_pool->pool_info.disk);
free(_pool->id);
free(_pool);
diff -r 4574c6f289f2 -r 261a49710d0c libxkutil/pool_parsing.h
--- a/libxkutil/pool_parsing.h Wed Apr 15 10:28:07 2009 -0700
+++ b/libxkutil/pool_parsing.h Thu Apr 16 11:14:10 2009 -0700
@@ -45,6 +45,7 @@
DISK_POOL_ISCSI,
DISK_POOL_LOGICAL} pool_type;
char *path;
+ char *device_path;
};
struct virt_pool {
diff -r 4574c6f289f2 -r 261a49710d0c libxkutil/xmlgen.c
--- a/libxkutil/xmlgen.c Wed Apr 15 10:28:07 2009 -0700
+++ b/libxkutil/xmlgen.c Thu Apr 16 11:14:10 2009 -0700
@@ -874,6 +874,8 @@
{
xmlNodePtr disk = NULL;
xmlNodePtr name = NULL;
+ xmlNodePtr src = NULL;
+ xmlNodePtr dev = NULL;
xmlNodePtr target = NULL;
xmlNodePtr path = NULL;
const char *type = NULL;
@@ -894,6 +896,21 @@
if (name == NULL)
goto out;
+ if (pool->device_path != NULL) {
+ src = xmlNewChild(disk, NULL, BAD_CAST "source", NULL);
+ if (src == NULL)
+ goto out;
+
+ dev = xmlNewChild(src, NULL, BAD_CAST "device", BAD_CAST NULL);
+ if (dev == NULL)
+ goto out;
+
+ if (xmlNewProp(dev,
+ BAD_CAST "path",
+ BAD_CAST pool->device_path) == NULL)
+ goto out;
+ }
+
target = xmlNewChild(disk, NULL, BAD_CAST "target", NULL);
if (target == NULL)
goto out;
diff -r 4574c6f289f2 -r 261a49710d0c schema/ResourceAllocationSettingData.mof
--- a/schema/ResourceAllocationSettingData.mof Wed Apr 15 10:28:07 2009 -0700
+++ b/schema/ResourceAllocationSettingData.mof Thu Apr 16 11:14:10 2009 -0700
@@ -207,6 +207,7 @@
"Disk, ISCSI, Logical"}]
uint16 Type;
string Path;
+ string DevicePath;
};
[Description ("KVM virtual disk pool settings"),
@@ -220,6 +221,7 @@
"Disk, ISCSI, Logical"}]
uint16 Type;
string Path;
+ string DevicePath;
};
[Description ("LXC virtual disk pool settings"),
@@ -233,5 +235,6 @@
"Disk, ISCSI, Logical"}]
uint16 Type;
string Path;
+ string DevicePath;
};
diff -r 4574c6f289f2 -r 261a49710d0c src/Virt_ResourcePoolConfigurationService.c
--- a/src/Virt_ResourcePoolConfigurationService.c Wed Apr 15 10:28:07 2009 -0700
+++ b/src/Virt_ResourcePoolConfigurationService.c Thu Apr 16 11:14:10 2009 -0700
@@ -114,6 +114,25 @@
}
#if VIR_USE_LIBVIRT_STORAGE
+static void init_disk_pool(struct virt_pool *pool)
+{
+ pool->pool_info.disk.device_path = NULL;
+ pool->pool_info.disk.path = NULL;
+}
+
+static const char *disk_fs_pool(CMPIInstance *inst,
+ struct virt_pool *pool)
+{
+ const char *val = NULL;
+
+ if (cu_get_str_prop(inst, "DevicePath", &val) != CMPI_RC_OK)
+ return "Missing `DevicePath' property";
+
+ pool->pool_info.disk.device_path = strdup(val);
+
+ return NULL;
+}
+
static const char *disk_rasd_to_pool(CMPIInstance *inst,
struct virt_pool *pool)
{
@@ -124,8 +143,19 @@
if (cu_get_u16_prop(inst, "Type", &type) != CMPI_RC_OK)
return "Missing `Type' property";
- if (type != DISK_POOL_DIR)
+ init_disk_pool(pool);
+
+ switch (type) {
+ case DISK_POOL_DIR:
+ break;
+ case DISK_POOL_FS:
+ msg = disk_fs_pool(inst, pool);
+ if (msg != NULL)
+ goto out;
+ break;
+ default:
return "Storage pool type not supported";
+ }
pool->pool_info.disk.pool_type = type;
@@ -134,6 +164,7 @@
pool->pool_info.disk.path = strdup(val);
+ out:
return msg;
}
15 years, 8 months
diff -r ced161a81981 -r fd53d858ff5f suites/libvirt-cim/cimtest/ResourcePoolConfigurationService/04_CreateChildResourcePool.py
--- a/suites/libvirt-cim/cimtest/ResourcePoolConfigurationService/04_CreateChildResourcePool.py Wed Apr 15 20:19:31 2009 -0700
+++ b/suites/libvirt-cim/cimtest/ResourcePoolConfigurationService/04_CreateChildResourcePool.py Sun Apr 19 22:59:10 2009 -0700
@@ -41,8 +41,8 @@
#
# REVISIT :
# --------
# As of now the CreateChildResourcePool() simply throws an Exception.
# We must improve this tc once the service is implemented.
#
# -Date: 20.02.2008
@@ -52,32 +52,100 @@
from XenKvmLib import rpcs_service
from CimTest.Globals import logger
from CimTest.ReturnCodes import FAIL, PASS
-from XenKvmLib.const import do_main, platform_sup
+from XenKvmLib.const import do_main, platform_sup, get_provider_version
from XenKvmLib.classes import get_typed_class
+from pywbem.cim_obj import CIMInstanceName, CIMInstance
+from XenKvmLib.enumclass import EnumInstances
+from XenKvmLib.common_util import destroy_netpool
cim_errno = pywbem.CIM_ERR_NOT_SUPPORTED
cim_mname = "CreateChildResourcePool"
+libvirt_cim_child_pool_rev = 837
+test_pool = ["routedpool", "natpool", "isolatedpool"]
+
+def verify_pool(pool_list, poolname):
+ status = FAIL
+ if len(pool_list) < 1:
+ logger.error("Return %i instances, expected at least one instance",
+ len(pool_list))
+ return FAIL
+
+ for i in range(0, len(pool_list)):
+ ret_pool = pool_list[i].InstanceID
+ if ret_pool == poolname:
+ status = PASS
+ break
+ elif ret_pool != poolname and i == len(pool_list)-1:
+ logger.error("Can not find expected pool")
+
+ return status
@do_main(platform_sup)
def main():
options = main.options
rpcs_conn = eval("rpcs_service." + get_typed_class(options.virt, \
"ResourcePoolConfigurationService"))(options.ip)
- try:
- rpcs_conn.CreateChildResourcePool()
- except pywbem.CIMError, (err_no, desc):
- if err_no == cim_errno :
- logger.info("Got expected exception for '%s' service", cim_mname)
- logger.info("Errno is '%s' ", err_no)
- logger.info("Error string is '%s'", desc)
- return PASS
- else:
- logger.error("Unexpected rc code %s and description %s\n",
- err_no, desc)
- return FAIL
-
- logger.error("The execution should not have reached here!!")
- return FAIL
+
+ curr_cim_rev, changeset = get_provider_version(options.virt, options.ip)
+ if curr_cim_rev < libvirt_cim_child_pool_rev:
+ try:
+ rpcs_conn.CreateChildResourcePool()
+ except pywbem.CIMError, (err_no, desc):
+ if err_no == cim_errno :
+ logger.info("Got expected exception for '%s'service", cim_mname)
+ logger.info("Errno is '%s' ", err_no)
+ logger.info("Error string is '%s'", desc)
+ return PASS
+ else:
+ logger.error("Unexpected rc code %s and description %s\n",
+ err_no, desc)
+ return FAIL
+ elif curr_cim_rev >= libvirt_cim_child_pool_rev:
+ nprasd = get_typed_class(options.virt,
+ 'NetPoolResourceAllocationSettingData')
+ for i in range(0, len(test_pool)):
+ np_id = 'NetworkPool/%s' % test_pool[i]
+ iname = CIMInstanceName(nprasd,
+ namespace = 'root/virt',
+ keybindings = {'InstanceID':np_id})
+ np_prop = {
+ "Address" : "192.168.0.30",
+ "Netmask" : "255.255.255.0",
+ "IPRangeStart" : "192.168.0.31",
+ "IPRangeEnd" : "192.168.0.57",
+ }
+ if test_pool == "routedpool":
+ np_prop["ForwardMode"] = "route eth1"
+ elif test_pool == "natpool":
+ np_prop["ForwardMode"] = "nat"
+
+ nrasd = CIMInstance(nprasd, path = iname, properties = np_prop)
+ try:
+ rpcs_conn.CreateChildResourcePool(ElementName=test_pool[i],
+ Settings=[nrasd.tomof()])
+ except pywbem.CIMError, details:
+ logger.error("Invoke CreateChildResourcePool() error when "
+ "create %s", np_id)
+ logger.error(details)
+ return FAIL
+
+ try:
+ np = get_typed_class(options.virt, 'NetworkPool')
+ netpool = EnumInstances(options.ip, np)
+ status = verify_pool(netpool, np_id)
+ if status != PASS:
+ raise Exception("Error in networkpool verification")
+
+ destroy_netpool(options.ip, options.virt, test_pool[i])
+ if status != PASS:
+ raise Exception("Unable to destroy networkpool %s"
+ % test_pool[i])
+ except Exception, details:
+ logger.error(detatils)
+ return FAIL
+
+ return status
+
if __name__ == "__main__":
sys.exit(main())
15 years, 8 months
@@ -41,8 +41,8 @@
# REVISIT :
# --------
-# As of now the CreateChildResourcePool() simply throws an Exception.
-# We must improve this tc once the service is implemented.
+# The CreateChildResourcePool() simply throws an Exception before the
+# changeset number of 839, and now the service is implemented.
#
# -Date: 20.02.2008
[PATCH] [TEST] Check to see if either qemu or qemu-kvm is present on the system
by Kaitlin Rupert
# HG changeset patch
# User Kaitlin Rupert <karupert(a)us.ibm.com>
# Date 1240184148 25200
# Node ID 6d914f871271725d4ed31abe4e35a5846b298fea
# Parent 3220adb67645abf3784876851de4eab6748e76b3
[TEST] Check to see if either qemu or qemu-kvm is present on the system
If the qemu binary doesn't exist, don't fail - check qemu-kvm first.
Signed-off-by: Kaitlin Rupert <karupert(a)us.ibm.com>